pub struct Compositor { /* private fields */ }Trait Implementations
Sourceimpl BufferHandler for Compositor
impl BufferHandler for Compositor
Sourcefn buffer_destroyed(&mut self, _buffer: &WlBuffer)
fn buffer_destroyed(&mut self, _buffer: &WlBuffer)
Called when the client has destroyed the buffer. Read more
Sourceimpl ClientDndGrabHandler for Compositor
impl ClientDndGrabHandler for Compositor
Sourceimpl CompositorHandler for Compositor
impl CompositorHandler for Compositor
Sourcefn compositor_state(&mut self) -> &mut CompositorState
fn compositor_state(&mut self) -> &mut CompositorState
CompositorState getter
Sourcefn client_compositor_state<'a>(
&self,
client: &'a Client,
) -> &'a CompositorClientState
fn client_compositor_state<'a>( &self, client: &'a Client, ) -> &'a CompositorClientState
CompositorClientState getter Read more
Sourcefn new_surface(&mut self, surface: &WlSurface)
fn new_surface(&mut self, surface: &WlSurface)
New surface handler. Read more
Sourceimpl DataDeviceHandler for Compositor
impl DataDeviceHandler for Compositor
Sourcefn data_device_state(&self) -> &DataDeviceState
fn data_device_state(&self) -> &DataDeviceState
DataDeviceState getter
Sourceimpl Dispatch<WlBuffer, Dmabuf> for Compositor
impl Dispatch<WlBuffer, Dmabuf> for Compositor
Sourceimpl Dispatch<WlBuffer, ShmBufferUserData> for Compositor
impl Dispatch<WlBuffer, ShmBufferUserData> for Compositor
Sourceimpl Dispatch<WlCallback, ()> for Compositor
impl Dispatch<WlCallback, ()> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WlCallback,
request: <WlCallback as Resource>::Request,
data: &(),
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WlCallback, request: <WlCallback as Resource>::Request, data: &(), dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<WlCompositor, ()> for Compositor
impl Dispatch<WlCompositor, ()> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WlCompositor,
request: <WlCompositor as Resource>::Request,
data: &(),
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WlCompositor, request: <WlCompositor as Resource>::Request, data: &(), dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<WlDataDeviceManager, ()> for Compositor
impl Dispatch<WlDataDeviceManager, ()> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WlDataDeviceManager,
request: <WlDataDeviceManager as Resource>::Request,
data: &(),
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WlDataDeviceManager, request: <WlDataDeviceManager as Resource>::Request, data: &(), dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<WlKeyboard, KeyboardUserData<Compositor>> for Compositor
impl Dispatch<WlKeyboard, KeyboardUserData<Compositor>> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WlKeyboard,
request: <WlKeyboard as Resource>::Request,
data: &KeyboardUserData<Compositor>,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WlKeyboard, request: <WlKeyboard as Resource>::Request, data: &KeyboardUserData<Compositor>, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &WlKeyboard,
data: &KeyboardUserData<Compositor>,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &WlKeyboard, data: &KeyboardUserData<Compositor>, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<WlOutput, OutputUserData> for Compositor
impl Dispatch<WlOutput, OutputUserData> for Compositor
Sourceimpl Dispatch<WlPointer, PointerUserData<Compositor>> for Compositor
impl Dispatch<WlPointer, PointerUserData<Compositor>> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WlPointer,
request: <WlPointer as Resource>::Request,
data: &PointerUserData<Compositor>,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WlPointer, request: <WlPointer as Resource>::Request, data: &PointerUserData<Compositor>, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &WlPointer,
data: &PointerUserData<Compositor>,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &WlPointer, data: &PointerUserData<Compositor>, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<WlRegion, RegionUserData> for Compositor
impl Dispatch<WlRegion, RegionUserData> for Compositor
Sourceimpl Dispatch<WlSeat, SeatUserData<Compositor>> for Compositor
impl Dispatch<WlSeat, SeatUserData<Compositor>> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WlSeat,
request: <WlSeat as Resource>::Request,
data: &SeatUserData<Compositor>,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WlSeat, request: <WlSeat as Resource>::Request, data: &SeatUserData<Compositor>, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &WlSeat,
data: &SeatUserData<Compositor>,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &WlSeat, data: &SeatUserData<Compositor>, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<WlShm, ()> for Compositor
impl Dispatch<WlShm, ()> for Compositor
Sourceimpl Dispatch<WlShmPool, ShmPoolUserData> for Compositor
impl Dispatch<WlShmPool, ShmPoolUserData> for Compositor
Sourceimpl Dispatch<WlSubcompositor, ()> for Compositor
impl Dispatch<WlSubcompositor, ()> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WlSubcompositor,
request: <WlSubcompositor as Resource>::Request,
data: &(),
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WlSubcompositor, request: <WlSubcompositor as Resource>::Request, data: &(), dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<WlSubsurface, SubsurfaceUserData> for Compositor
impl Dispatch<WlSubsurface, SubsurfaceUserData> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WlSubsurface,
request: <WlSubsurface as Resource>::Request,
data: &SubsurfaceUserData,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WlSubsurface, request: <WlSubsurface as Resource>::Request, data: &SubsurfaceUserData, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &WlSubsurface,
data: &SubsurfaceUserData,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &WlSubsurface, data: &SubsurfaceUserData, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<WlSurface, SurfaceUserData> for Compositor
impl Dispatch<WlSurface, SurfaceUserData> for Compositor
Sourceimpl Dispatch<WlTouch, TouchUserData<Compositor>> for Compositor
impl Dispatch<WlTouch, TouchUserData<Compositor>> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WlTouch,
request: <WlTouch as Resource>::Request,
data: &TouchUserData<Compositor>,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WlTouch, request: <WlTouch as Resource>::Request, data: &TouchUserData<Compositor>, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &WlTouch,
data: &TouchUserData<Compositor>,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &WlTouch, data: &TouchUserData<Compositor>, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<WpCursorShapeManagerV1, ()> for Compositor
impl Dispatch<WpCursorShapeManagerV1, ()> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WpCursorShapeManagerV1,
request: <WpCursorShapeManagerV1 as Resource>::Request,
data: &(),
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WpCursorShapeManagerV1, request: <WpCursorShapeManagerV1 as Resource>::Request, data: &(), dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<WpFractionalScaleManagerV1, ()> for Compositor
impl Dispatch<WpFractionalScaleManagerV1, ()> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WpFractionalScaleManagerV1,
request: <WpFractionalScaleManagerV1 as Resource>::Request,
data: &(),
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WpFractionalScaleManagerV1, request: <WpFractionalScaleManagerV1 as Resource>::Request, data: &(), dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<WpFractionalScaleV1, Weak<WlSurface>> for Compositor
impl Dispatch<WpFractionalScaleV1, Weak<WlSurface>> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WpFractionalScaleV1,
request: <WpFractionalScaleV1 as Resource>::Request,
data: &Weak<WlSurface>,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WpFractionalScaleV1, request: <WpFractionalScaleV1 as Resource>::Request, data: &Weak<WlSurface>, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<WpViewport, ViewportState> for Compositor
impl Dispatch<WpViewport, ViewportState> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WpViewport,
request: <WpViewport as Resource>::Request,
data: &ViewportState,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WpViewport, request: <WpViewport as Resource>::Request, data: &ViewportState, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &WpViewport,
data: &ViewportState,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &WpViewport, data: &ViewportState, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<WpViewporter, ()> for Compositor
impl Dispatch<WpViewporter, ()> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &WpViewporter,
request: <WpViewporter as Resource>::Request,
data: &(),
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &WpViewporter, request: <WpViewporter as Resource>::Request, data: &(), dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<XdgActivationTokenV1, ActivationTokenData> for Compositor
impl Dispatch<XdgActivationTokenV1, ActivationTokenData> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &XdgActivationTokenV1,
request: <XdgActivationTokenV1 as Resource>::Request,
data: &ActivationTokenData,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &XdgActivationTokenV1, request: <XdgActivationTokenV1 as Resource>::Request, data: &ActivationTokenData, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &XdgActivationTokenV1,
data: &ActivationTokenData,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &XdgActivationTokenV1, data: &ActivationTokenData, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<XdgActivationV1, ()> for Compositor
impl Dispatch<XdgActivationV1, ()> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &XdgActivationV1,
request: <XdgActivationV1 as Resource>::Request,
data: &(),
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &XdgActivationV1, request: <XdgActivationV1 as Resource>::Request, data: &(), dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<XdgPopup, XdgShellSurfaceUserData> for Compositor
impl Dispatch<XdgPopup, XdgShellSurfaceUserData> for Compositor
Sourceimpl Dispatch<XdgPositioner, XdgPositionerUserData> for Compositor
impl Dispatch<XdgPositioner, XdgPositionerUserData> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &XdgPositioner,
request: <XdgPositioner as Resource>::Request,
data: &XdgPositionerUserData,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &XdgPositioner, request: <XdgPositioner as Resource>::Request, data: &XdgPositionerUserData, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &XdgPositioner,
data: &XdgPositionerUserData,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &XdgPositioner, data: &XdgPositionerUserData, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<XdgSurface, XdgSurfaceUserData> for Compositor
impl Dispatch<XdgSurface, XdgSurfaceUserData> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &XdgSurface,
request: <XdgSurface as Resource>::Request,
data: &XdgSurfaceUserData,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &XdgSurface, request: <XdgSurface as Resource>::Request, data: &XdgSurfaceUserData, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &XdgSurface,
data: &XdgSurfaceUserData,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &XdgSurface, data: &XdgSurfaceUserData, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<XdgToplevel, XdgShellSurfaceUserData> for Compositor
impl Dispatch<XdgToplevel, XdgShellSurfaceUserData> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &XdgToplevel,
request: <XdgToplevel as Resource>::Request,
data: &XdgShellSurfaceUserData,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &XdgToplevel, request: <XdgToplevel as Resource>::Request, data: &XdgShellSurfaceUserData, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &XdgToplevel,
data: &XdgShellSurfaceUserData,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &XdgToplevel, data: &XdgShellSurfaceUserData, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<XdgToplevelIconManagerV1, ()> for Compositor
impl Dispatch<XdgToplevelIconManagerV1, ()> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &XdgToplevelIconManagerV1,
request: <XdgToplevelIconManagerV1 as Resource>::Request,
data: &(),
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &XdgToplevelIconManagerV1, request: <XdgToplevelIconManagerV1 as Resource>::Request, data: &(), dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<XdgToplevelIconV1, XdgToplevelIconUserData> for Compositor
impl Dispatch<XdgToplevelIconV1, XdgToplevelIconUserData> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &XdgToplevelIconV1,
request: <XdgToplevelIconV1 as Resource>::Request,
data: &XdgToplevelIconUserData,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &XdgToplevelIconV1, request: <XdgToplevelIconV1 as Resource>::Request, data: &XdgToplevelIconUserData, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &XdgToplevelIconV1,
data: &XdgToplevelIconUserData,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &XdgToplevelIconV1, data: &XdgToplevelIconUserData, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<XdgWmBase, XdgWmBaseUserData> for Compositor
impl Dispatch<XdgWmBase, XdgWmBaseUserData> for Compositor
Sourceimpl Dispatch<ZwpLinuxBufferParamsV1, DmabufParamsData> for Compositor
impl Dispatch<ZwpLinuxBufferParamsV1, DmabufParamsData> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &ZwpLinuxBufferParamsV1,
request: <ZwpLinuxBufferParamsV1 as Resource>::Request,
data: &DmabufParamsData,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &ZwpLinuxBufferParamsV1, request: <ZwpLinuxBufferParamsV1 as Resource>::Request, data: &DmabufParamsData, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &ZwpLinuxBufferParamsV1,
data: &DmabufParamsData,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &ZwpLinuxBufferParamsV1, data: &DmabufParamsData, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<ZwpLinuxDmabufFeedbackV1, DmabufFeedbackData> for Compositor
impl Dispatch<ZwpLinuxDmabufFeedbackV1, DmabufFeedbackData> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &ZwpLinuxDmabufFeedbackV1,
request: <ZwpLinuxDmabufFeedbackV1 as Resource>::Request,
data: &DmabufFeedbackData,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &ZwpLinuxDmabufFeedbackV1, request: <ZwpLinuxDmabufFeedbackV1 as Resource>::Request, data: &DmabufFeedbackData, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &ZwpLinuxDmabufFeedbackV1,
data: &DmabufFeedbackData,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &ZwpLinuxDmabufFeedbackV1, data: &DmabufFeedbackData, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<ZwpLinuxDmabufV1, DmabufData> for Compositor
impl Dispatch<ZwpLinuxDmabufV1, DmabufData> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &ZwpLinuxDmabufV1,
request: <ZwpLinuxDmabufV1 as Resource>::Request,
data: &DmabufData,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &ZwpLinuxDmabufV1, request: <ZwpLinuxDmabufV1 as Resource>::Request, data: &DmabufData, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &ZwpLinuxDmabufV1,
data: &DmabufData,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &ZwpLinuxDmabufV1, data: &DmabufData, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<ZwpPrimarySelectionDeviceManagerV1, ()> for Compositor
impl Dispatch<ZwpPrimarySelectionDeviceManagerV1, ()> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &ZwpPrimarySelectionDeviceManagerV1,
request: <ZwpPrimarySelectionDeviceManagerV1 as Resource>::Request,
data: &(),
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &ZwpPrimarySelectionDeviceManagerV1, request: <ZwpPrimarySelectionDeviceManagerV1 as Resource>::Request, data: &(), dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<ZwpTextInputManagerV3, ()> for Compositor
impl Dispatch<ZwpTextInputManagerV3, ()> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &ZwpTextInputManagerV3,
request: <ZwpTextInputManagerV3 as Resource>::Request,
data: &(),
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &ZwpTextInputManagerV3, request: <ZwpTextInputManagerV3 as Resource>::Request, data: &(), dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<ZwpTextInputV3, TextInputUserData> for Compositor
impl Dispatch<ZwpTextInputV3, TextInputUserData> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &ZwpTextInputV3,
request: <ZwpTextInputV3 as Resource>::Request,
data: &TextInputUserData,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &ZwpTextInputV3, request: <ZwpTextInputV3 as Resource>::Request, data: &TextInputUserData, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &ZwpTextInputV3,
data: &TextInputUserData,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &ZwpTextInputV3, data: &TextInputUserData, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<ZxdgDecorationManagerV1, ()> for Compositor
impl Dispatch<ZxdgDecorationManagerV1, ()> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &ZxdgDecorationManagerV1,
request: <ZxdgDecorationManagerV1 as Resource>::Request,
data: &(),
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &ZxdgDecorationManagerV1, request: <ZxdgDecorationManagerV1 as Resource>::Request, data: &(), dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<ZxdgOutputManagerV1, ()> for Compositor
impl Dispatch<ZxdgOutputManagerV1, ()> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &ZxdgOutputManagerV1,
request: <ZxdgOutputManagerV1 as Resource>::Request,
data: &(),
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &ZxdgOutputManagerV1, request: <ZxdgOutputManagerV1 as Resource>::Request, data: &(), dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourceimpl Dispatch<ZxdgOutputV1, XdgOutputUserData> for Compositor
impl Dispatch<ZxdgOutputV1, XdgOutputUserData> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &ZxdgOutputV1,
request: <ZxdgOutputV1 as Resource>::Request,
data: &XdgOutputUserData,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &ZxdgOutputV1, request: <ZxdgOutputV1 as Resource>::Request, data: &XdgOutputUserData, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &ZxdgOutputV1,
data: &XdgOutputUserData,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &ZxdgOutputV1, data: &XdgOutputUserData, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl Dispatch<ZxdgToplevelDecorationV1, ToplevelSurface> for Compositor
impl Dispatch<ZxdgToplevelDecorationV1, ToplevelSurface> for Compositor
Sourcefn request(
state: &mut Self,
client: &Client,
resource: &ZxdgToplevelDecorationV1,
request: <ZxdgToplevelDecorationV1 as Resource>::Request,
data: &ToplevelSurface,
dhandle: &DisplayHandle,
data_init: &mut DataInit<'_, Self>,
)
fn request( state: &mut Self, client: &Client, resource: &ZxdgToplevelDecorationV1, request: <ZxdgToplevelDecorationV1 as Resource>::Request, data: &ToplevelSurface, dhandle: &DisplayHandle, data_init: &mut DataInit<'_, Self>, )
Called when a request from a client is processed. Read more
Sourcefn destroyed(
state: &mut Self,
client: ClientId,
resource: &ZxdgToplevelDecorationV1,
data: &ToplevelSurface,
)
fn destroyed( state: &mut Self, client: ClientId, resource: &ZxdgToplevelDecorationV1, data: &ToplevelSurface, )
Called when the object this user data is associated with has been destroyed. Read more
Sourceimpl DmabufHandler for Compositor
impl DmabufHandler for Compositor
Sourcefn dmabuf_state(&mut self) -> &mut DmabufState
fn dmabuf_state(&mut self) -> &mut DmabufState
Returns a mutable reference to the
DmabufState delegate type.Sourcefn dmabuf_imported(
&mut self,
_global: &DmabufGlobal,
_dmabuf: Dmabuf,
notifier: ImportNotifier,
)
fn dmabuf_imported( &mut self, _global: &DmabufGlobal, _dmabuf: Dmabuf, notifier: ImportNotifier, )
Sourcefn new_surface_feedback(
&mut self,
_surface: &WlSurface,
_global: &DmabufGlobal,
) -> Option<DmabufFeedback>
fn new_surface_feedback( &mut self, _surface: &WlSurface, _global: &DmabufGlobal, ) -> Option<DmabufFeedback>
This function allows to override the default
DmabufFeedback for a surface Read moreSourceimpl FractionalScaleHandler for Compositor
impl FractionalScaleHandler for Compositor
Sourcefn new_fractional_scale(&mut self, _surface: WlSurface)
fn new_fractional_scale(&mut self, _surface: WlSurface)
A new fractional scale was instantiated
Sourceimpl GlobalDispatch<WlCompositor, ()> for Compositor
impl GlobalDispatch<WlCompositor, ()> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<WlCompositor>,
global_data: &(),
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<WlCompositor>, global_data: &(), data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourceimpl GlobalDispatch<WlDataDeviceManager, ()> for Compositor
impl GlobalDispatch<WlDataDeviceManager, ()> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<WlDataDeviceManager>,
global_data: &(),
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<WlDataDeviceManager>, global_data: &(), data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourceimpl GlobalDispatch<WlOutput, WlOutputData> for Compositor
impl GlobalDispatch<WlOutput, WlOutputData> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<WlOutput>,
global_data: &WlOutputData,
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<WlOutput>, global_data: &WlOutputData, data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourceimpl GlobalDispatch<WlSeat, SeatGlobalData<Compositor>> for Compositor
impl GlobalDispatch<WlSeat, SeatGlobalData<Compositor>> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<WlSeat>,
global_data: &SeatGlobalData<Compositor>,
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<WlSeat>, global_data: &SeatGlobalData<Compositor>, data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourcefn can_view(client: Client, global_data: &SeatGlobalData<Compositor>) -> bool
fn can_view(client: Client, global_data: &SeatGlobalData<Compositor>) -> bool
Checks if the global should be advertised to some client. Read more
Sourceimpl GlobalDispatch<WlShm, ()> for Compositor
impl GlobalDispatch<WlShm, ()> for Compositor
Sourceimpl GlobalDispatch<WlSubcompositor, ()> for Compositor
impl GlobalDispatch<WlSubcompositor, ()> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<WlSubcompositor>,
global_data: &(),
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<WlSubcompositor>, global_data: &(), data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourceimpl GlobalDispatch<WpCursorShapeManagerV1, ()> for Compositor
impl GlobalDispatch<WpCursorShapeManagerV1, ()> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<WpCursorShapeManagerV1>,
global_data: &(),
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<WpCursorShapeManagerV1>, global_data: &(), data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourceimpl GlobalDispatch<WpFractionalScaleManagerV1, ()> for Compositor
impl GlobalDispatch<WpFractionalScaleManagerV1, ()> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<WpFractionalScaleManagerV1>,
global_data: &(),
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<WpFractionalScaleManagerV1>, global_data: &(), data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourceimpl GlobalDispatch<WpViewporter, ()> for Compositor
impl GlobalDispatch<WpViewporter, ()> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<WpViewporter>,
global_data: &(),
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<WpViewporter>, global_data: &(), data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourceimpl GlobalDispatch<XdgActivationV1, ()> for Compositor
impl GlobalDispatch<XdgActivationV1, ()> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<XdgActivationV1>,
global_data: &(),
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<XdgActivationV1>, global_data: &(), data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourceimpl GlobalDispatch<XdgToplevelIconManagerV1, XdgToplevelIconManagerUserData> for Compositor
impl GlobalDispatch<XdgToplevelIconManagerV1, XdgToplevelIconManagerUserData> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<XdgToplevelIconManagerV1>,
global_data: &XdgToplevelIconManagerUserData,
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<XdgToplevelIconManagerV1>, global_data: &XdgToplevelIconManagerUserData, data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourceimpl GlobalDispatch<XdgWmBase, ()> for Compositor
impl GlobalDispatch<XdgWmBase, ()> for Compositor
Sourceimpl GlobalDispatch<ZwpLinuxDmabufV1, DmabufGlobalData> for Compositor
impl GlobalDispatch<ZwpLinuxDmabufV1, DmabufGlobalData> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<ZwpLinuxDmabufV1>,
global_data: &DmabufGlobalData,
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<ZwpLinuxDmabufV1>, global_data: &DmabufGlobalData, data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourceimpl GlobalDispatch<ZwpTextInputManagerV3, ()> for Compositor
impl GlobalDispatch<ZwpTextInputManagerV3, ()> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<ZwpTextInputManagerV3>,
global_data: &(),
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<ZwpTextInputManagerV3>, global_data: &(), data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourceimpl GlobalDispatch<ZxdgDecorationManagerV1, XdgDecorationManagerGlobalData> for Compositor
impl GlobalDispatch<ZxdgDecorationManagerV1, XdgDecorationManagerGlobalData> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<ZxdgDecorationManagerV1>,
global_data: &XdgDecorationManagerGlobalData,
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<ZxdgDecorationManagerV1>, global_data: &XdgDecorationManagerGlobalData, data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourceimpl GlobalDispatch<ZxdgOutputManagerV1, ()> for Compositor
impl GlobalDispatch<ZxdgOutputManagerV1, ()> for Compositor
Sourcefn bind(
state: &mut Self,
dhandle: &DisplayHandle,
client: &Client,
resource: New<ZxdgOutputManagerV1>,
global_data: &(),
data_init: &mut DataInit<'_, Self>,
)
fn bind( state: &mut Self, dhandle: &DisplayHandle, client: &Client, resource: New<ZxdgOutputManagerV1>, global_data: &(), data_init: &mut DataInit<'_, Self>, )
Called when a client has bound this global. Read more
Sourceimpl OutputHandler for Compositor
impl OutputHandler for Compositor
Sourcefn output_bound(&mut self, _output: Output, _wl_output: WlOutput)
fn output_bound(&mut self, _output: Output, _wl_output: WlOutput)
A client bound a new
wl_output instance.Sourceimpl PrimarySelectionHandler for Compositor
impl PrimarySelectionHandler for Compositor
Sourcefn primary_selection_state(&self) -> &PrimarySelectionState
fn primary_selection_state(&self) -> &PrimarySelectionState
PrimarySelectionState getter.
Sourceimpl SeatHandler for Compositor
impl SeatHandler for Compositor
Sourcetype KeyboardFocus = WlSurface
type KeyboardFocus = WlSurface
Type used to represent the target currently holding the keyboard focus
Sourcetype PointerFocus = WlSurface
type PointerFocus = WlSurface
Type used to represent the target currently holding the pointer focus
Sourcetype TouchFocus = WlSurface
type TouchFocus = WlSurface
Type used to represent the target currently holding the touch focus
Sourcefn seat_state(&mut self) -> &mut SeatState<Self>
fn seat_state(&mut self) -> &mut SeatState<Self>
SeatState getter
Sourcefn cursor_image(&mut self, _seat: &Seat<Self>, _image: CursorImageStatus)
fn cursor_image(&mut self, _seat: &Seat<Self>, _image: CursorImageStatus)
Callback that will be notified whenever a client requests to set a custom cursor image.
Sourcefn focus_changed(&mut self, seat: &Seat<Self>, focused: Option<&WlSurface>)
fn focus_changed(&mut self, seat: &Seat<Self>, focused: Option<&WlSurface>)
Callback that will be notified whenever the focus of the seat changes.
Sourcefn led_state_changed(&mut self, _seat: &Seat<Self>, _led_state: LedState)
fn led_state_changed(&mut self, _seat: &Seat<Self>, _led_state: LedState)
Callback that will be notified whenever the keyboard led state changes.
Sourceimpl SelectionHandler for Compositor
impl SelectionHandler for Compositor
Sourcefn new_selection(
&mut self,
ty: SelectionTarget,
source: Option<SelectionSource>,
seat: Seat<Self>,
)
fn new_selection( &mut self, ty: SelectionTarget, source: Option<SelectionSource>, seat: Seat<Self>, )
A client has set the selection
Sourcefn send_selection(
&mut self,
_ty: SelectionTarget,
_mime_type: String,
fd: OwnedFd,
_seat: Seat<Self>,
user_data: &Self::SelectionUserData,
)
fn send_selection( &mut self, _ty: SelectionTarget, _mime_type: String, fd: OwnedFd, _seat: Seat<Self>, user_data: &Self::SelectionUserData, )
A client requested to read the server-set selection. Read more
Sourceimpl ServerDndGrabHandler for Compositor
impl ServerDndGrabHandler for Compositor
Sourcefn accept(&mut self, mime_type: Option<String>, seat: Seat<Self>)
fn accept(&mut self, mime_type: Option<String>, seat: Seat<Self>)
The client can accept the given mime type. Read more
Sourcefn action(&mut self, action: DndAction, seat: Seat<Self>)
fn action(&mut self, action: DndAction, seat: Seat<Self>)
The client chose an action Read more
Sourceimpl ShmHandler for Compositor
impl ShmHandler for Compositor
Sourceimpl TabletSeatHandler for Compositor
impl TabletSeatHandler for Compositor
Sourcefn tablet_tool_image(
&mut self,
tool: &TabletToolDescriptor,
image: CursorImageStatus,
)
fn tablet_tool_image( &mut self, tool: &TabletToolDescriptor, image: CursorImageStatus, )
Callback that will be notified whenever a client requests to set a custom tool image.
Sourceimpl XdgActivationHandler for Compositor
impl XdgActivationHandler for Compositor
Sourcefn activation_state(&mut self) -> &mut XdgActivationState
fn activation_state(&mut self) -> &mut XdgActivationState
Returns the activation state.
Sourcefn request_activation(
&mut self,
_token: XdgActivationToken,
_token_data: XdgActivationTokenData,
_surface: WlSurface,
)
fn request_activation( &mut self, _token: XdgActivationToken, _token_data: XdgActivationTokenData, _surface: WlSurface, )
A client has requested surface activation. Read more
Sourcefn token_created(
&mut self,
token: XdgActivationToken,
data: XdgActivationTokenData,
) -> bool
fn token_created( &mut self, token: XdgActivationToken, data: XdgActivationTokenData, ) -> bool
A client has created a new token. Read more
Sourceimpl XdgDecorationHandler for Compositor
impl XdgDecorationHandler for Compositor
Sourcefn new_decoration(&mut self, toplevel: ToplevelSurface)
fn new_decoration(&mut self, toplevel: ToplevelSurface)
Notification the client supports server side decoration on the toplevel.
Sourcefn request_mode(&mut self, toplevel: ToplevelSurface, _mode: DecorationMode)
fn request_mode(&mut self, toplevel: ToplevelSurface, _mode: DecorationMode)
Notification the client prefers the provided decoration decoration mode on the toplevel.
Sourcefn unset_mode(&mut self, toplevel: ToplevelSurface)
fn unset_mode(&mut self, toplevel: ToplevelSurface)
Notification the client does not prefer a particular decoration mode on the toplevel.
Sourceimpl XdgShellHandler for Compositor
impl XdgShellHandler for Compositor
Sourcefn xdg_shell_state(&mut self) -> &mut XdgShellState
fn xdg_shell_state(&mut self) -> &mut XdgShellState
XdgShellState getter
Sourcefn new_toplevel(&mut self, surface: ToplevelSurface)
fn new_toplevel(&mut self, surface: ToplevelSurface)
A new toplevel surface was created Read more
Sourcefn toplevel_destroyed(&mut self, surface: ToplevelSurface)
fn toplevel_destroyed(&mut self, surface: ToplevelSurface)
A toplevel surface was destroyed.
Sourcefn new_popup(&mut self, _surface: PopupSurface, _positioner: PositionerState)
fn new_popup(&mut self, _surface: PopupSurface, _positioner: PositionerState)
A new popup surface was created Read more
Sourcefn grab(&mut self, _surface: PopupSurface, _seat: WlSeat, _serial: Serial)
fn grab(&mut self, _surface: PopupSurface, _seat: WlSeat, _serial: Serial)
This popup requests a grab of the pointer Read more
Sourcefn reposition_request(
&mut self,
_surface: PopupSurface,
_positioner: PositionerState,
_token: u32,
)
fn reposition_request( &mut self, _surface: PopupSurface, _positioner: PositionerState, _token: u32, )
A client requested a reposition, providing a new positioner for a popup. Read more
Sourcefn new_client(&mut self, client: ShellClient)
fn new_client(&mut self, client: ShellClient)
A new shell client was instantiated
Sourcefn client_pong(&mut self, client: ShellClient)
fn client_pong(&mut self, client: ShellClient)
The pong for a pending ping of this shell client was received Read more
Sourcefn move_request(
&mut self,
surface: ToplevelSurface,
seat: WlSeat,
serial: Serial,
)
fn move_request( &mut self, surface: ToplevelSurface, seat: WlSeat, serial: Serial, )
The client requested the start of an interactive move for this surface
Sourcefn resize_request(
&mut self,
surface: ToplevelSurface,
seat: WlSeat,
serial: Serial,
edges: ResizeEdge,
)
fn resize_request( &mut self, surface: ToplevelSurface, seat: WlSeat, serial: Serial, edges: ResizeEdge, )
The client requested the start of an interactive resize for this surface
Sourcefn maximize_request(&mut self, surface: ToplevelSurface)
fn maximize_request(&mut self, surface: ToplevelSurface)
A toplevel surface requested to be maximized
Sourcefn unmaximize_request(&mut self, surface: ToplevelSurface)
fn unmaximize_request(&mut self, surface: ToplevelSurface)
A toplevel surface requested to stop being maximized
Sourcefn fullscreen_request(
&mut self,
surface: ToplevelSurface,
output: Option<WlOutput>,
)
fn fullscreen_request( &mut self, surface: ToplevelSurface, output: Option<WlOutput>, )
A toplevel surface requested to be set fullscreen
Sourcefn unfullscreen_request(&mut self, surface: ToplevelSurface)
fn unfullscreen_request(&mut self, surface: ToplevelSurface)
A toplevel surface request to stop being fullscreen
Sourcefn minimize_request(&mut self, surface: ToplevelSurface)
fn minimize_request(&mut self, surface: ToplevelSurface)
A toplevel surface requested to be minimized
The client requests the window menu to be displayed on this surface at this location Read more
Sourcefn ack_configure(&mut self, surface: WlSurface, configure: Configure)
fn ack_configure(&mut self, surface: WlSurface, configure: Configure)
A surface has acknowledged a configure serial.
Sourcefn client_destroyed(&mut self, client: ShellClient)
fn client_destroyed(&mut self, client: ShellClient)
A shell client was destroyed.
Sourcefn popup_destroyed(&mut self, surface: PopupSurface)
fn popup_destroyed(&mut self, surface: PopupSurface)
A popup surface was destroyed.
Sourcefn app_id_changed(&mut self, surface: ToplevelSurface)
fn app_id_changed(&mut self, surface: ToplevelSurface)
The toplevel surface set a different app id.
Sourcefn title_changed(&mut self, surface: ToplevelSurface)
fn title_changed(&mut self, surface: ToplevelSurface)
The toplevel surface set a different title.
Sourcefn parent_changed(&mut self, surface: ToplevelSurface)
fn parent_changed(&mut self, surface: ToplevelSurface)
The parent of a toplevel surface has changed.
Sourceimpl XdgToplevelIconHandler for Compositor
impl XdgToplevelIconHandler for Compositor
Sourcefn set_icon(&mut self, toplevel: XdgToplevel, wl_surface: WlSurface)
fn set_icon(&mut self, toplevel: XdgToplevel, wl_surface: WlSurface)
Called when icon becomes pending, and awaits surface commit.
Icon is stored in wl_surface ToplevelIconCachedState