pub enum CompositorCommand {
Show 20 variants
KeyInput {
surface_id: u16,
keycode: u32,
pressed: bool,
},
PointerMotion {
surface_id: u16,
x: f64,
y: f64,
},
PointerButton {
surface_id: u16,
button: u32,
pressed: bool,
},
PointerAxis {
surface_id: u16,
axis: u8,
value: f64,
},
SurfaceResize {
surface_id: u16,
width: u16,
height: u16,
scale_120: u16,
},
SurfaceFocus {
surface_id: u16,
},
SurfaceClose {
surface_id: u16,
},
ClipboardOffer {
mime_type: String,
data: Vec<u8>,
},
Capture {
surface_id: u16,
scale_120: u16,
reply: SyncSender<Option<(u32, u32, Vec<u8>)>>,
},
RequestFrame {
surface_id: u16,
},
ReleaseKeys {
keycodes: Vec<u32>,
},
ClipboardListMimes {
reply: SyncSender<Vec<String>>,
},
ClipboardGet {
mime_type: String,
reply: SyncSender<Option<Vec<u8>>>,
},
SetExternalOutputBuffers {
surface_id: u32,
buffers: Vec<ExternalOutputBuffer>,
},
TextInput {
text: String,
},
SetRefreshRate {
mhz: u32,
},
SetVulkanEncoder {
surface_id: u32,
codec: u8,
qp: u8,
width: u32,
height: u32,
},
RequestVulkanKeyframe {
surface_id: u32,
},
DestroyVulkanEncoder {
surface_id: u32,
},
Shutdown,
}Variants
KeyInput
PointerMotion
PointerButton
PointerAxis
SurfaceResize
SurfaceFocus
SurfaceClose
ClipboardOffer
Capture
RequestFrame
ReleaseKeys
ClipboardListMimes
List available clipboard MIME types.
Fields

reply: SyncSender<Vec<String>>ClipboardGet
Read clipboard content for a specific MIME type.
SetExternalOutputBuffers
Set externally-allocated DMA-BUF fds as GPU renderer output targets for a specific surface.
TextInput
Synthesize text input as key press/release sequences.
SetRefreshRate
Update the advertised output refresh rate (millihertz).
SetVulkanEncoder
Set up a Vulkan Video encoder for a surface.
RequestVulkanKeyframe
Request a keyframe from the Vulkan Video encoder for a surface.
DestroyVulkanEncoder
Destroy the Vulkan Video encoder for a surface.
Shutdown