pub enum CompositorCommand {
KeyInput {
surface_id: u16,
keycode: u32,
pressed: bool,
},
PointerMotion {
surface_id: u16,
x: f64,
y: f64,
},
PointerButton {
surface_id: u16,
button: u32,
pressed: bool,
},
PointerAxis {
surface_id: u16,
axis: u8,
value: f64,
},
SurfaceResize {
surface_id: u16,
width: u16,
height: u16,
scale_120: u16,
},
SurfaceFocus {
surface_id: u16,
},
SurfaceClose {
surface_id: u16,
},
ClipboardOffer {
surface_id: u16,
mime_type: String,
data: Vec<u8>,
},
Capture {
surface_id: u16,
reply: SyncSender<Option<(u32, u32, Vec<u8>)>>,
},
RequestFrame {
surface_id: u16,
},
ReleaseKeys {
keycodes: Vec<u32>,
},
Shutdown,
}Variants
KeyInput
PointerMotion
PointerButton
PointerAxis
SurfaceResize
Fields
SurfaceFocus
SurfaceClose
ClipboardOffer
Capture
RequestFrame
Fire pending wl_surface.frame callbacks for a surface so the client will paint and commit its next frame. Send this when the server is ready to consume a new frame (streaming or capture).
ReleaseKeys
Release the given keys (evdev keycodes) in the compositor’s XKB state. Sent by the server when a transport client disconnects so that stuck modifiers / runaway key-repeat don’t persist.
Shutdown